==> jc-1.4.0.tar.gz: java/util/AbstractMap__24BasicMapEntry.h <==
// class java.util.AbstractMap$BasicMapEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_AbstractMap__24BasicMapEntry_H_
#define _JC_java_util_AbstractMap__24BasicMapEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	_jc_java_util_AbstractMap__24BasicMapEntry$sub_refs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	_jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$refs	_jc_java_util_AbstractMap__24BasicMapEntry$refs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$nonrefs	_jc_java_util_AbstractMap__24BasicMapEntry$nonrefs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$object	_jc_java_util_AbstractMap__24BasicMapEntry$object;

typedef const struct _jc_java_util_AbstractMap__24BasicMapEntry$vmethods	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods;
typedef const struct _jc_java_util_AbstractMap__24BasicMapEntry$vtable	_jc_java_util_AbstractMap__24BasicMapEntry$vtable;
typedef const struct _jc_java_util_AbstractMap__24BasicMapEntry$vtype	_jc_java_util_AbstractMap__24BasicMapEntry$vtype;

// Constructors
extern void _jc_java_util_AbstractMap__24BasicMapEntry$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_util_AbstractMap__24BasicMapEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
extern jint _jc_java_util_AbstractMap__24BasicMapEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_AbstractMap__24BasicMapEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *);
};

// Vtable
struct _jc_java_util_AbstractMap__24BasicMapEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
};

// Vtype
struct _jc_java_util_AbstractMap__24BasicMapEntry$vtype {
	_jc_type			type;
	_jc_java_util_AbstractMap__24BasicMapEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs {
	struct _jc_java_lang_Object$object	*key;
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_java_util_AbstractMap__24BasicMapEntry$refs {
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractMap__24BasicMapEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
};

// Object instance structure
struct _jc_java_util_AbstractMap__24BasicMapEntry$object {
	_jc_java_util_AbstractMap__24BasicMapEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractMap__24BasicMapEntry$vtype	*vtype;
	_jc_java_util_AbstractMap__24BasicMapEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractMap__24BasicMapEntry$vtype _jc_java_util_AbstractMap__24BasicMapEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractMap__24BasicMapEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractMap__24BasicMapEntry$class_object;

#endif	/* _JC_java_util_AbstractMap__24BasicMapEntry_H_ */

==> jc-1.4.6.tar.gz: java/util/AbstractMap__24BasicMapEntry.h <==
// class java.util.AbstractMap$BasicMapEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_AbstractMap__24BasicMapEntry_H_
#define _JC_java_util_AbstractMap__24BasicMapEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	_jc_java_util_AbstractMap__24BasicMapEntry$sub_refs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	_jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$refs	_jc_java_util_AbstractMap__24BasicMapEntry$refs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$nonrefs	_jc_java_util_AbstractMap__24BasicMapEntry$nonrefs;
typedef struct _jc_java_util_AbstractMap__24BasicMapEntry$object	_jc_java_util_AbstractMap__24BasicMapEntry$object;

typedef const struct _jc_java_util_AbstractMap__24BasicMapEntry$vmethods	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods;
typedef const struct _jc_java_util_AbstractMap__24BasicMapEntry$vtable	_jc_java_util_AbstractMap__24BasicMapEntry$vtable;
typedef const struct _jc_java_util_AbstractMap__24BasicMapEntry$vtype	_jc_java_util_AbstractMap__24BasicMapEntry$vtype;

// Constructors
extern void _jc_java_util_AbstractMap__24BasicMapEntry$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_AbstractMap__24BasicMapEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_AbstractMap__24BasicMapEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_AbstractMap__24BasicMapEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_AbstractMap__24BasicMapEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_AbstractMap__24BasicMapEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_AbstractMap__24BasicMapEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_AbstractMap__24BasicMapEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
};

// Vtype
struct _jc_java_util_AbstractMap__24BasicMapEntry$vtype {
	_jc_type			type;
	_jc_java_util_AbstractMap__24BasicMapEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs {
	struct _jc_java_lang_Object$object	*key;
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_java_util_AbstractMap__24BasicMapEntry$refs {
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractMap__24BasicMapEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
};

// Object instance structure
struct _jc_java_util_AbstractMap__24BasicMapEntry$object {
	_jc_java_util_AbstractMap__24BasicMapEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractMap__24BasicMapEntry$vtype	*vtype;
	_jc_java_util_AbstractMap__24BasicMapEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractMap__24BasicMapEntry$vtype _jc_java_util_AbstractMap__24BasicMapEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractMap__24BasicMapEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractMap__24BasicMapEntry$class_object;

#endif	/* _JC_java_util_AbstractMap__24BasicMapEntry_H_ */
